////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  qll_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "qll_1_0_0.h"
#include "parametersetmanager.h"

QLL_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "calibration") == 0)
    {
        __result = calibration.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ml_isp_tuning") == 0)
    {
        __result = ml_isp_tuning.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_qll10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "calibration") == 0)
    {
        __result = calibration.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ml_isp_tuning") == 0)
    {
        __result = ml_isp_tuning.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_qll10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // calibration
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("calibration", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "calibration") == 0)
    {
        __result = calibration.GetInfo(&__path[__pos], __info);
    }

    // ml_isp_tuning
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_isp_tuning", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ml_isp_tuning") == 0)
    {
        __result = ml_isp_tuning.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_qll10_reserveType::calibrationStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lux_index_for_mode_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)lux_index_for_mode_enable, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lens_focal_length_eqv_mm") == 0)
    {
        ParameterUtils::DoubleToString((double)lens_focal_length_eqv_mm, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ois_compensation_range_deg") == 0)
    {
        ParameterUtils::DoubleToString((double)ois_compensation_range_deg, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "gyro_noise_floor_thresh_rad_per_sec") == 0)
    {
        ParameterUtils::DoubleToString((double)gyro_noise_floor_thresh_rad_per_sec, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_mfnr_frame_count") == 0)
    {
        ParameterUtils::DoubleToString((double)max_mfnr_frame_count, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_zsl_buffer_frame_count") == 0)
    {
        ParameterUtils::DoubleToString((double)max_zsl_buffer_frame_count, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_qll10_reserveType::calibrationStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lux_index_for_mode_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lux_index_for_mode_enable = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lens_focal_length_eqv_mm") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lens_focal_length_eqv_mm = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ois_compensation_range_deg") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ois_compensation_range_deg = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "gyro_noise_floor_thresh_rad_per_sec") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            gyro_noise_floor_thresh_rad_per_sec = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_mfnr_frame_count") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_mfnr_frame_count = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_zsl_buffer_frame_count") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_zsl_buffer_frame_count = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_qll10_reserveType::calibrationStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lux_index_for_mode_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lux_index_for_mode_enable", ParameterParserDataType::Float, (double)lux_index_for_mode_enable));
    }
    else if (PARAMETER_STRCMP(__name, "lux_index_for_mode_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)lux_index_for_mode_enable));
    }

    // lens_focal_length_eqv_mm
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_focal_length_eqv_mm", ParameterParserDataType::Float, (double)lens_focal_length_eqv_mm));
    }
    else if (PARAMETER_STRCMP(__name, "lens_focal_length_eqv_mm") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)lens_focal_length_eqv_mm));
    }

    // ois_compensation_range_deg
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ois_compensation_range_deg", ParameterParserDataType::Float, (double)ois_compensation_range_deg));
    }
    else if (PARAMETER_STRCMP(__name, "ois_compensation_range_deg") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)ois_compensation_range_deg));
    }

    // gyro_noise_floor_thresh_rad_per_sec
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gyro_noise_floor_thresh_rad_per_sec", ParameterParserDataType::Float, (double)gyro_noise_floor_thresh_rad_per_sec));
    }
    else if (PARAMETER_STRCMP(__name, "gyro_noise_floor_thresh_rad_per_sec") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)gyro_noise_floor_thresh_rad_per_sec));
    }

    // max_mfnr_frame_count
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_mfnr_frame_count", ParameterParserDataType::UInt32, (double)max_mfnr_frame_count, 0));
    }
    else if (PARAMETER_STRCMP(__name, "max_mfnr_frame_count") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)max_mfnr_frame_count, 0));
    }

    // max_zsl_buffer_frame_count
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_zsl_buffer_frame_count", ParameterParserDataType::Int32, (double)max_zsl_buffer_frame_count, 0));
    }
    else if (PARAMETER_STRCMP(__name, "max_zsl_buffer_frame_count") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)max_zsl_buffer_frame_count, 0));
    }

    return __result;
}

bool chromatix_qll10_reserveType::ml_isp_tuningStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)ml_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_qll10_reserveType::ml_isp_tuningStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ml_enable = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_qll10_reserveType::ml_isp_tuningStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ml_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_enable", ParameterParserDataType::UInt32, (double)ml_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ml_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ml_enable, 0));
    }

    return __result;
}

bool qll10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "calibration") == 0)
    {
        __result = calibration.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "motion_awareness_tuning") == 0)
    {
        __result = motion_awareness_tuning.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ml_isp_tuning") == 0)
    {
        __result = ml_isp_tuning.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool qll10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "calibration") == 0)
    {
        __result = calibration.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "motion_awareness_tuning") == 0)
    {
        __result = motion_awareness_tuning.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ml_isp_tuning") == 0)
    {
        __result = ml_isp_tuning.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool qll10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // calibration
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("calibration", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "calibration") == 0)
    {
        __result = calibration.GetInfo(&__path[__pos], __info);
    }

    // motion_awareness_tuning
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("motion_awareness_tuning", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "motion_awareness_tuning") == 0)
    {
        __result = motion_awareness_tuning.GetInfo(&__path[__pos], __info);
    }

    // ml_isp_tuning
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_isp_tuning", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ml_isp_tuning") == 0)
    {
        __result = ml_isp_tuning.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_param_1") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_1, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_2") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_2, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_1_tab") == 0)
    {
        __result = res_lut_param_1_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_2_tab") == 0)
    {
        __result = res_lut_param_2_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_param_1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_2") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_2 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_1_tab") == 0)
    {
        __result = res_lut_param_1_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_2_tab") == 0)
    {
        __result = res_lut_param_2_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_param_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_1", ParameterParserDataType::Float, (double)res_param_1));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_1));
    }

    // res_param_2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_2", ParameterParserDataType::Float, (double)res_param_2));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_2") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_2));
    }

    // res_lut_param_1_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_1_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_1_tab") == 0)
    {
        __result = res_lut_param_1_tab.GetInfo(&__path[__pos], __info);
    }

    // res_lut_param_2_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_2_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_2_tab") == 0)
    {
        __result = res_lut_param_2_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::res_lut_param_1_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_1") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_1[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_1[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::res_lut_param_1_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_1") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_1[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_1[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::res_lut_param_1_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_1", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::res_lut_param_2_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_2") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_2[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_2[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::res_lut_param_2_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_2") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_2[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_2[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::calibrationStruct::res_lut_param_2_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_2", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "requested_max_shot_to_shot_duration_sec") == 0)
    {
        ParameterUtils::DoubleToString((double)requested_max_shot_to_shot_duration_sec, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_processing_duration_overhead_sec") == 0)
    {
        ParameterUtils::DoubleToString((double)requested_max_processing_duration_overhead_sec, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_single_frame_exp_sec") == 0)
    {
        ParameterUtils::DoubleToString((double)requested_max_single_frame_exp_sec, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "zsl_aec_change_factor_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)zsl_aec_change_factor_threshold, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "accepted_long_frame_motion_blur") == 0)
    {
        ParameterUtils::DoubleToString((double)accepted_long_frame_motion_blur, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "local_motion_weight") == 0)
    {
        ParameterUtils::DoubleToString((double)local_motion_weight, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "local_motion_sensitivity") == 0)
    {
        ParameterUtils::DoubleToString((double)local_motion_sensitivity, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "expose_long_as_med_factor_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)expose_long_as_med_factor_threshold, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_max_shot_to_shot_duration_sec") == 0)
    {
        ParameterUtils::DoubleToString((double)tripod_detected_max_shot_to_shot_duration_sec, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_max_single_frame_exp_sec") == 0)
    {
        ParameterUtils::DoubleToString((double)tripod_detected_max_single_frame_exp_sec, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_local_motion_weight") == 0)
    {
        ParameterUtils::DoubleToString((double)tripod_detected_local_motion_weight, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_3") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_3, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_4") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_4, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_3_tab") == 0)
    {
        __result = res_lut_param_3_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_4_tab") == 0)
    {
        __result = res_lut_param_4_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "requested_max_shot_to_shot_duration_sec") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            requested_max_shot_to_shot_duration_sec = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_processing_duration_overhead_sec") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            requested_max_processing_duration_overhead_sec = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_single_frame_exp_sec") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            requested_max_single_frame_exp_sec = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "zsl_aec_change_factor_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            zsl_aec_change_factor_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "accepted_long_frame_motion_blur") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            accepted_long_frame_motion_blur = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "local_motion_weight") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            local_motion_weight = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "local_motion_sensitivity") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            local_motion_sensitivity = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "expose_long_as_med_factor_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            expose_long_as_med_factor_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_max_shot_to_shot_duration_sec") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            tripod_detected_max_shot_to_shot_duration_sec = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_max_single_frame_exp_sec") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            tripod_detected_max_single_frame_exp_sec = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_local_motion_weight") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            tripod_detected_local_motion_weight = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_3") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_3 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_4") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_4 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_3_tab") == 0)
    {
        __result = res_lut_param_3_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_4_tab") == 0)
    {
        __result = res_lut_param_4_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // requested_max_shot_to_shot_duration_sec
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("requested_max_shot_to_shot_duration_sec", ParameterParserDataType::Float, (double)requested_max_shot_to_shot_duration_sec));
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_shot_to_shot_duration_sec") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)requested_max_shot_to_shot_duration_sec));
    }

    // requested_max_processing_duration_overhead_sec
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("requested_max_processing_duration_overhead_sec", ParameterParserDataType::Float, (double)requested_max_processing_duration_overhead_sec));
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_processing_duration_overhead_sec") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)requested_max_processing_duration_overhead_sec));
    }

    // requested_max_single_frame_exp_sec
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("requested_max_single_frame_exp_sec", ParameterParserDataType::Float, (double)requested_max_single_frame_exp_sec));
    }
    else if (PARAMETER_STRCMP(__name, "requested_max_single_frame_exp_sec") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)requested_max_single_frame_exp_sec));
    }

    // zsl_aec_change_factor_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("zsl_aec_change_factor_threshold", ParameterParserDataType::Float, (double)zsl_aec_change_factor_threshold));
    }
    else if (PARAMETER_STRCMP(__name, "zsl_aec_change_factor_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)zsl_aec_change_factor_threshold));
    }

    // accepted_long_frame_motion_blur
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("accepted_long_frame_motion_blur", ParameterParserDataType::Float, (double)accepted_long_frame_motion_blur));
    }
    else if (PARAMETER_STRCMP(__name, "accepted_long_frame_motion_blur") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)accepted_long_frame_motion_blur));
    }

    // local_motion_weight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("local_motion_weight", ParameterParserDataType::Float, (double)local_motion_weight));
    }
    else if (PARAMETER_STRCMP(__name, "local_motion_weight") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)local_motion_weight));
    }

    // local_motion_sensitivity
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("local_motion_sensitivity", ParameterParserDataType::Float, (double)local_motion_sensitivity));
    }
    else if (PARAMETER_STRCMP(__name, "local_motion_sensitivity") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)local_motion_sensitivity));
    }

    // expose_long_as_med_factor_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("expose_long_as_med_factor_threshold", ParameterParserDataType::Float, (double)expose_long_as_med_factor_threshold));
    }
    else if (PARAMETER_STRCMP(__name, "expose_long_as_med_factor_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)expose_long_as_med_factor_threshold));
    }

    // tripod_detected_max_shot_to_shot_duration_sec
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("tripod_detected_max_shot_to_shot_duration_sec", ParameterParserDataType::Float, (double)tripod_detected_max_shot_to_shot_duration_sec));
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_max_shot_to_shot_duration_sec") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)tripod_detected_max_shot_to_shot_duration_sec));
    }

    // tripod_detected_max_single_frame_exp_sec
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("tripod_detected_max_single_frame_exp_sec", ParameterParserDataType::Float, (double)tripod_detected_max_single_frame_exp_sec));
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_max_single_frame_exp_sec") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)tripod_detected_max_single_frame_exp_sec));
    }

    // tripod_detected_local_motion_weight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("tripod_detected_local_motion_weight", ParameterParserDataType::Float, (double)tripod_detected_local_motion_weight));
    }
    else if (PARAMETER_STRCMP(__name, "tripod_detected_local_motion_weight") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)tripod_detected_local_motion_weight));
    }

    // res_param_3
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_3", ParameterParserDataType::Float, (double)res_param_3));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_3") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_3));
    }

    // res_param_4
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_4", ParameterParserDataType::Float, (double)res_param_4));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_4") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_4));
    }

    // res_lut_param_3_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_3_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_3_tab") == 0)
    {
        __result = res_lut_param_3_tab.GetInfo(&__path[__pos], __info);
    }

    // res_lut_param_4_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_4_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_4_tab") == 0)
    {
        __result = res_lut_param_4_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_3_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_3") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_3[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_3[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_3_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_3") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_3[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_3[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_3_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_3
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_3", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_4_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_4") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_4[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_4[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_4_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_4") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_4[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_4[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_4_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_4
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_4", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_nr_tab") == 0)
    {
        __result = ml_nr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ml_hf_tab") == 0)
    {
        __result = ml_hf_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ml_rnr_tab") == 0)
    {
        __result = ml_rnr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ml_model_sel") == 0)
    {
        ParameterUtils::DoubleToString((double)ml_model_sel, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_5") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_5, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_6") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_6, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_5_tab") == 0)
    {
        __result = res_lut_param_5_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_6_tab") == 0)
    {
        __result = res_lut_param_6_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_nr_tab") == 0)
    {
        __result = ml_nr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ml_hf_tab") == 0)
    {
        __result = ml_hf_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ml_rnr_tab") == 0)
    {
        __result = ml_rnr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ml_model_sel") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ml_model_sel = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_5") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_5 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_6") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_6 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_5_tab") == 0)
    {
        __result = res_lut_param_5_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_6_tab") == 0)
    {
        __result = res_lut_param_6_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ml_nr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_nr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ml_nr_tab") == 0)
    {
        __result = ml_nr_tab.GetInfo(&__path[__pos], __info);
    }

    // ml_hf_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_hf_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ml_hf_tab") == 0)
    {
        __result = ml_hf_tab.GetInfo(&__path[__pos], __info);
    }

    // ml_rnr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_rnr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ml_rnr_tab") == 0)
    {
        __result = ml_rnr_tab.GetInfo(&__path[__pos], __info);
    }

    // ml_model_sel
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_model_sel", ParameterParserDataType::UInt32, (double)ml_model_sel, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ml_model_sel") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ml_model_sel, 0));
    }

    // res_param_5
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_5", ParameterParserDataType::Float, (double)res_param_5));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_5") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_5));
    }

    // res_param_6
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_6", ParameterParserDataType::Float, (double)res_param_6));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_6") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_6));
    }

    // res_lut_param_5_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_5_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_5_tab") == 0)
    {
        __result = res_lut_param_5_tab.GetInfo(&__path[__pos], __info);
    }

    // res_lut_param_6_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_6_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_6_tab") == 0)
    {
        __result = res_lut_param_6_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_nr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_nr") == 0)
    {
        if (__index < 6)
        {
            ParameterUtils::DoubleToString((double)ml_nr[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 6; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ml_nr[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_nr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_nr") == 0)
    {
        if (__index < 6)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ml_nr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 6)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ml_nr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_nr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ml_nr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_nr", ParameterParserDataType::Float, true, false, 6));
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_hf_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_hf") == 0)
    {
        if (__index < 6)
        {
            ParameterUtils::DoubleToString((double)ml_hf[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 6; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ml_hf[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_hf_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_hf") == 0)
    {
        if (__index < 6)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ml_hf[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 6)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ml_hf[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_hf_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ml_hf
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_hf", ParameterParserDataType::Float, true, false, 6));
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_rnr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_rnr") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)ml_rnr[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ml_rnr[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_rnr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ml_rnr") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ml_rnr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ml_rnr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_rnr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ml_rnr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ml_rnr", ParameterParserDataType::Float, true, false, 17));
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_5_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_5") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_5[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_5[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_5_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_5") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_5[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_5[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_5_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_5
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_5", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_6_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_6") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_6[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_6[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_6_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_6") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_6[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_6[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_6_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_6
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_6", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool mod_qll10_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "qll10_rgn_data") == 0)
    {
        __result = qll10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_qll10_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "qll10_rgn_data") == 0)
    {
        __result = qll10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_qll10_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // qll10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("qll10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "qll10_rgn_data") == 0)
    {
        __result = qll10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_qll10_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_qll10_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_qll10_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_qll10_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_qll10_aec_data") == 0)
    {
        if (__index < mod_qll10_aec_dataCount)
        {
            __result = mod_qll10_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_qll10_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_qll10_aec_data") == 0)
    {
        if (__index < mod_qll10_aec_dataCount)
        {
            __result = mod_qll10_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_qll10_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_qll10_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_qll10_aec_data", ParameterParserDataType::Structure, true, false, mod_qll10_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_qll10_aec_data") == 0)
    {
        if (__index < mod_qll10_aec_dataCount)
        {
            __result = mod_qll10_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_qll10_aec_dataCount));
        }
    }

    return __result;
}

bool mod_qll10_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_qll10_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_qll10_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_qll10_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_qll10_hdr_aec_data") == 0)
    {
        if (__index < mod_qll10_hdr_aec_dataCount)
        {
            __result = mod_qll10_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_qll10_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_qll10_hdr_aec_data") == 0)
    {
        if (__index < mod_qll10_hdr_aec_dataCount)
        {
            __result = mod_qll10_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_qll10_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_qll10_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_qll10_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_qll10_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_qll10_hdr_aec_data") == 0)
    {
        if (__index < mod_qll10_hdr_aec_dataCount)
        {
            __result = mod_qll10_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_qll10_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool chromatix_qll10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_qll10_drc_gain_data") == 0)
    {
        if (__index < mod_qll10_drc_gain_dataCount)
        {
            __result = mod_qll10_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_qll10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_qll10_drc_gain_data") == 0)
    {
        if (__index < mod_qll10_drc_gain_dataCount)
        {
            __result = mod_qll10_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_qll10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_qll10_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_qll10_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_qll10_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_qll10_drc_gain_data") == 0)
    {
        if (__index < mod_qll10_drc_gain_dataCount)
        {
            __result = mod_qll10_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_qll10_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_qll10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_qll10_reserve") == 0)
    {
        __result = chromatix_qll10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_qll10_core") == 0)
    {
        __result = chromatix_qll10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_qll10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_qll10_reserve") == 0)
    {
        __result = chromatix_qll10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_qll10_core") == 0)
    {
        __result = chromatix_qll10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_qll10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_qll10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_qll10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_qll10_reserve") == 0)
    {
        __result = chromatix_qll10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_qll10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_qll10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_qll10_core") == 0)
    {
        __result = chromatix_qll10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_qll10Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_qll10Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_qll10Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Int32, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enable, 0));
    }

    return __result;
}

bool chromatix_qll10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_qll10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_qll10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_qll10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_qll10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_qll10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_qll10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_qll10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_qll10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 3));
    }

    return __result;
}

bool chromatix_qll10Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_qll10Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_qll10Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_qll10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_qll10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_qll10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_qll10TypeClass::chromatix_qll10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_qll10_reserve);
    PARAMETER_INITIALIZE(chromatix_qll10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_qll10TypeClass::chromatix_qll10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_qll10_reserve);
    PARAMETER_INITIALIZE(chromatix_qll10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_qll10TypeClass::~chromatix_qll10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_qll10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "qll10_sw")) == 0)
    {
        name = "qll10_sw";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_qll10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(calibration);
    PARAMETER_INITIALIZE(ml_isp_tuning);

    result = calibration.Load(entry, alignment);
    if (result)
    {
        result = ml_isp_tuning.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_qll10_reserveType_calibrationStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10_reserveType::calibrationStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lux_index_for_mode_enable);
    PARAMETER_INITIALIZE(lens_focal_length_eqv_mm);
    PARAMETER_INITIALIZE(ois_compensation_range_deg);
    PARAMETER_INITIALIZE(gyro_noise_floor_thresh_rad_per_sec);
    PARAMETER_INITIALIZE(max_mfnr_frame_count);
    PARAMETER_INITIALIZE(max_zsl_buffer_frame_count);

    SYMBOL_TABLE_ENTRY_READ(entry, result, lux_index_for_mode_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lens_focal_length_eqv_mm, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, ois_compensation_range_deg, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, gyro_noise_floor_thresh_rad_per_sec, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_mfnr_frame_count, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_zsl_buffer_frame_count, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_qll10_reserveType_ml_isp_tuningStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10_reserveType::ml_isp_tuningStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ml_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, ml_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(calibration);
    PARAMETER_INITIALIZE(motion_awareness_tuning);
    PARAMETER_INITIALIZE(ml_isp_tuning);

    result = calibration.Load(entry, alignment);
    if (result)
    {
        result = motion_awareness_tuning.Load(entry, alignment);
    }
    if (result)
    {
        result = ml_isp_tuning.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_calibrationStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::calibrationStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_param_1);
    PARAMETER_INITIALIZE(res_param_2);
    PARAMETER_INITIALIZE(res_lut_param_1_tab);
    PARAMETER_INITIALIZE(res_lut_param_2_tab);

    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_2, alignment)
    if (result)
    {
        result = res_lut_param_1_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = res_lut_param_2_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_calibrationStruct_res_lut_param_1_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::calibrationStruct::res_lut_param_1_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_1);

    result = entry->ReadArray(res_lut_param_1, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_calibrationStruct_res_lut_param_2_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::calibrationStruct::res_lut_param_2_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_2);

    result = entry->ReadArray(res_lut_param_2, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_motion_awareness_tuningStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::motion_awareness_tuningStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(requested_max_shot_to_shot_duration_sec);
    PARAMETER_INITIALIZE(requested_max_processing_duration_overhead_sec);
    PARAMETER_INITIALIZE(requested_max_single_frame_exp_sec);
    PARAMETER_INITIALIZE(zsl_aec_change_factor_threshold);
    PARAMETER_INITIALIZE(accepted_long_frame_motion_blur);
    PARAMETER_INITIALIZE(local_motion_weight);
    PARAMETER_INITIALIZE(local_motion_sensitivity);
    PARAMETER_INITIALIZE(expose_long_as_med_factor_threshold);
    PARAMETER_INITIALIZE(tripod_detected_max_shot_to_shot_duration_sec);
    PARAMETER_INITIALIZE(tripod_detected_max_single_frame_exp_sec);
    PARAMETER_INITIALIZE(tripod_detected_local_motion_weight);
    PARAMETER_INITIALIZE(res_param_3);
    PARAMETER_INITIALIZE(res_param_4);
    PARAMETER_INITIALIZE(res_lut_param_3_tab);
    PARAMETER_INITIALIZE(res_lut_param_4_tab);

    SYMBOL_TABLE_ENTRY_READ(entry, result, requested_max_shot_to_shot_duration_sec, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, requested_max_processing_duration_overhead_sec, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, requested_max_single_frame_exp_sec, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, zsl_aec_change_factor_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, accepted_long_frame_motion_blur, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, local_motion_weight, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, local_motion_sensitivity, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, expose_long_as_med_factor_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, tripod_detected_max_shot_to_shot_duration_sec, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, tripod_detected_max_single_frame_exp_sec, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, tripod_detected_local_motion_weight, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_3, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_4, alignment)
    if (result)
    {
        result = res_lut_param_3_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = res_lut_param_4_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_motion_awareness_tuningStruct_res_lut_param_3_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_3_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_3);

    result = entry->ReadArray(res_lut_param_3, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_motion_awareness_tuningStruct_res_lut_param_4_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::motion_awareness_tuningStruct::res_lut_param_4_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_4);

    result = entry->ReadArray(res_lut_param_4, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_ml_isp_tuningStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::ml_isp_tuningStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ml_nr_tab);
    PARAMETER_INITIALIZE(ml_hf_tab);
    PARAMETER_INITIALIZE(ml_rnr_tab);
    PARAMETER_INITIALIZE(ml_model_sel);
    PARAMETER_INITIALIZE(res_param_5);
    PARAMETER_INITIALIZE(res_param_6);
    PARAMETER_INITIALIZE(res_lut_param_5_tab);
    PARAMETER_INITIALIZE(res_lut_param_6_tab);

    result = ml_nr_tab.Load(entry, alignment);
    if (result)
    {
        result = ml_hf_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = ml_rnr_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, ml_model_sel, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_5, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_6, alignment)
    if (result)
    {
        result = res_lut_param_5_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = res_lut_param_6_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_ml_isp_tuningStruct_ml_nr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_nr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ml_nr);

    result = entry->ReadArray(ml_nr, 6, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_ml_isp_tuningStruct_ml_hf_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_hf_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ml_hf);

    result = entry->ReadArray(ml_hf, 6, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_ml_isp_tuningStruct_ml_rnr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::ml_isp_tuningStruct::ml_rnr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ml_rnr);

    result = entry->ReadArray(ml_rnr, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_ml_isp_tuningStruct_res_lut_param_5_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_5_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_5);

    result = entry->ReadArray(res_lut_param_5, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load qll10_rgn_dataType_ml_isp_tuningStruct_res_lut_param_6_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool qll10_rgn_dataType::ml_isp_tuningStruct::res_lut_param_6_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_6);

    result = entry->ReadArray(res_lut_param_6, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_qll10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_qll10_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(qll10_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = qll10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_qll10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_qll10_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_qll10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_qll10_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_qll10_aec_data);


    // Reading Array mod_qll10_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_qll10_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_qll10_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_qll10_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_qll10_aec_dataDupInfo = pointerEntry->GetDupObject(mod_qll10_aec_dataCount, file, line);
            if (mod_qll10_aec_dataDupInfo != nullptr && mod_qll10_aec_dataDupInfo->Object != nullptr)
            {
                mod_qll10_aec_data = (mod_qll10_aec_dataType*)mod_qll10_aec_dataDupInfo->Object;
                if (mod_qll10_aec_data == nullptr)
                {
                    if (mod_qll10_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_qll10_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_qll10_aec_dataDupInfo->File, mod_qll10_aec_dataDupInfo->Line, mod_qll10_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_qll10_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_qll10_aec_dataDupInfo->Line, mod_qll10_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_qll10_aec_data == nullptr)
            {
                if (result && mod_qll10_aec_dataCount > 0)
                {
                    mod_qll10_aec_data = PARAMETER_NEW mod_qll10_aec_dataType[mod_qll10_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_qll10_aec_data, mod_qll10_aec_dataCount, file, line);
                }
                if (!result || mod_qll10_aec_data == nullptr)
                {
                    if (mod_qll10_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_qll10_aec_data\n");
                    }
                    mod_qll10_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_qll10_aec_dataCount; i++)
                {
                    result = mod_qll10_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_qll10_aec_data == nullptr)
        {
            mod_qll10_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_qll10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_qll10_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_qll10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_qll10_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_qll10_hdr_aec_data);


    // Reading Array mod_qll10_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_qll10_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_qll10_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_qll10_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_qll10_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_qll10_hdr_aec_dataCount, file, line);
            if (mod_qll10_hdr_aec_dataDupInfo != nullptr && mod_qll10_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_qll10_hdr_aec_data = (mod_qll10_hdr_aec_dataType*)mod_qll10_hdr_aec_dataDupInfo->Object;
                if (mod_qll10_hdr_aec_data == nullptr)
                {
                    if (mod_qll10_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_qll10_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_qll10_hdr_aec_dataDupInfo->File, mod_qll10_hdr_aec_dataDupInfo->Line, mod_qll10_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_qll10_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_qll10_hdr_aec_dataDupInfo->Line, mod_qll10_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_qll10_hdr_aec_data == nullptr)
            {
                if (result && mod_qll10_hdr_aec_dataCount > 0)
                {
                    mod_qll10_hdr_aec_data = PARAMETER_NEW mod_qll10_hdr_aec_dataType[mod_qll10_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_qll10_hdr_aec_data, mod_qll10_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_qll10_hdr_aec_data == nullptr)
                {
                    if (mod_qll10_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_qll10_hdr_aec_data\n");
                    }
                    mod_qll10_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_qll10_hdr_aec_dataCount; i++)
                {
                    result = mod_qll10_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_qll10_hdr_aec_data == nullptr)
        {
            mod_qll10_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_qll10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_qll10_drc_gain_data);


    // Reading Array mod_qll10_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_qll10_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_qll10_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_qll10_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_qll10_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_qll10_drc_gain_dataCount, file, line);
            if (mod_qll10_drc_gain_dataDupInfo != nullptr && mod_qll10_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_qll10_drc_gain_data = (mod_qll10_drc_gain_dataType*)mod_qll10_drc_gain_dataDupInfo->Object;
                if (mod_qll10_drc_gain_data == nullptr)
                {
                    if (mod_qll10_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_qll10_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_qll10_drc_gain_dataDupInfo->File, mod_qll10_drc_gain_dataDupInfo->Line, mod_qll10_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_qll10_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_qll10_drc_gain_dataDupInfo->Line, mod_qll10_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_qll10_drc_gain_data == nullptr)
            {
                if (result && mod_qll10_drc_gain_dataCount > 0)
                {
                    mod_qll10_drc_gain_data = PARAMETER_NEW mod_qll10_drc_gain_dataType[mod_qll10_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_qll10_drc_gain_data, mod_qll10_drc_gain_dataCount, file, line);
                }
                if (!result || mod_qll10_drc_gain_data == nullptr)
                {
                    if (mod_qll10_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_qll10_drc_gain_data\n");
                    }
                    mod_qll10_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_qll10_drc_gain_dataCount; i++)
                {
                    result = mod_qll10_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_qll10_drc_gain_data == nullptr)
        {
            mod_qll10_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_qll10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_qll10_reserve);
    PARAMETER_INITIALIZE(chromatix_qll10_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_qll10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_qll10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 3; i++)
    {
        result = chromatix_qll10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_qll10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_qll10_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_qll10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_qll10_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_qll10_aec_data))
    {
        PARAMETER_DELETE[] mod_qll10_aec_data;
    }
    mod_qll10_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_qll10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_qll10_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_qll10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_qll10_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_qll10_hdr_aec_dataCount; i++)
    {
        mod_qll10_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_qll10_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_qll10_hdr_aec_data;
    }
    mod_qll10_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_qll10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_qll10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_qll10_drc_gain_dataCount; i++)
    {
        mod_qll10_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_qll10_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_qll10_drc_gain_data;
    }
    mod_qll10_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_qll10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_qll10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_qll10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_qll10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_qll10Type::Release()
{
    ((chromatix_qll10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_qll10Type::GetModified()
{
    return ((chromatix_qll10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_qll10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_qll10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_qll10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_qll10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_qll10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_qll10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_qll10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_qll10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_qll10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_qll10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_qll10TypeClass::Release()
{
    ParameterModule::Release();
}

QLL_1_0_0_NAMESPACE_END
